FixedDurationStrategy

Struct FixedDurationStrategy 

pub struct FixedDurationStrategy {
    pub chunk_duration: Duration,
    pub snap_tolerance: Duration,
    pub reassembly: ReassemblyPlan,
    pub timeout_multiplier: f64,
}
Split media at fixed duration intervals.

Simple strategy that creates equal-sized chunks. Chunk boundaries are snapped to the nearest provided boundary point (keyframe/silence).

Fields

chunk_duration: Duration

Target duration per chunk.

snap_tolerance: Duration

Maximum allowed deviation from target when snapping to boundaries.

reassembly: ReassemblyPlan

How to reassemble chunks.

timeout_multiplier: f64

Timeout multiplier per chunk (based on chunk duration).

Implementations

Source

impl FixedDurationStrategy

pub fn with_chunk_duration(self, duration: Duration) -> Self

Create a strategy with the given chunk duration.

pub fn with_snap_tolerance(self, tolerance: Duration) -> Self

Set the snap tolerance.

pub fn with_reassembly(self, reassembly: ReassemblyPlan) -> Self

Set the reassembly plan.

pub fn with_timeout_multiplier(self, multiplier: f64) -> Self

Set the timeout multiplier.