pub struct Timestamp(pub u64);Expand description
A time point in microseconds from the start of the media.
Microsecond precision matches FFmpeg’s internal timestamp resolution, avoiding precision loss during conversion.
Tuple Fields
0: u64Implementations
Sourceimpl Timestamp
impl Timestamp
Sourcepub fn from_millis(ms: u64) -> Self
pub fn from_millis(ms: u64) -> Self
Create from milliseconds.
Sourcepub fn from_micros(us: u64) -> Self
pub fn from_micros(us: u64) -> Self
Create from microseconds.
Sourcepub fn from_seconds(s: f64) -> Self
pub fn from_seconds(s: f64) -> Self
Create from seconds (floating point).
Sourcepub fn as_seconds(&self) -> f64
pub fn as_seconds(&self) -> f64
Get the value in seconds (floating point).
Sourcepub fn as_duration(&self) -> Duration
pub fn as_duration(&self) -> Duration
Convert to a Duration.
Sourcepub fn to_ffmpeg_time(&self) -> String
pub fn to_ffmpeg_time(&self) -> String
Format as “HH:MM:SS.mmm” (FFmpeg-compatible).