pub struct FixedDurationStrategy {
pub chunk_duration: Duration,
pub snap_tolerance: Duration,
pub reassembly: ReassemblyPlan,
pub timeout_multiplier: f64,
}Expand description
Split media at fixed duration intervals.
Simple strategy that creates equal-sized chunks. Chunk boundaries are snapped to the nearest provided boundary point (keyframe/silence).
Fields
chunk_duration: DurationTarget duration per chunk.
snap_tolerance: DurationMaximum allowed deviation from target when snapping to boundaries.
reassembly: ReassemblyPlanHow to reassemble chunks.
timeout_multiplier: f64Timeout multiplier per chunk (based on chunk duration).
Implementations
Sourceimpl FixedDurationStrategy
impl FixedDurationStrategy
Sourcepub fn with_chunk_duration(self, duration: Duration) -> Self
pub fn with_chunk_duration(self, duration: Duration) -> Self
Create a strategy with the given chunk duration.
Sourcepub fn with_snap_tolerance(self, tolerance: Duration) -> Self
pub fn with_snap_tolerance(self, tolerance: Duration) -> Self
Set the snap tolerance.
Sourcepub fn with_reassembly(self, reassembly: ReassemblyPlan) -> Self
pub fn with_reassembly(self, reassembly: ReassemblyPlan) -> Self
Set the reassembly plan.
Sourcepub fn with_timeout_multiplier(self, multiplier: f64) -> Self
pub fn with_timeout_multiplier(self, multiplier: f64) -> Self
Set the timeout multiplier.