pub struct Resolution {
pub width: u32,
pub height: u32,
}Expand description
Width × Height in pixels.
Fields
width: u32Width in pixels.
height: u32Height in pixels.
Implementations
Sourceimpl Resolution
impl Resolution
Sourcepub fn aspect_ratio(&self) -> (u32, u32)
pub fn aspect_ratio(&self) -> (u32, u32)
Aspect ratio as a simplified fraction (e.g., (16, 9)).
Sourcepub fn aspect_ratio_f64(&self) -> f64
pub fn aspect_ratio_f64(&self) -> f64
Aspect ratio as a floating-point value (width / height).
Sourcepub fn is_portrait(&self) -> bool
pub fn is_portrait(&self) -> bool
Whether the image is taller than it is wide.
Sourcepub fn is_landscape(&self) -> bool
pub fn is_landscape(&self) -> bool
Whether the image is wider than it is tall.
Sourcepub fn pixel_count(&self) -> u64
pub fn pixel_count(&self) -> u64
Total pixel count.
Sourcepub fn scale_to_fit(&self, max_width: u32, max_height: u32) -> Self
pub fn scale_to_fit(&self, max_width: u32, max_height: u32) -> Self
Scale to fit within the given bounds, preserving aspect ratio.
Sourcepub fn scale_to_fill(&self, width: u32, height: u32) -> Self
pub fn scale_to_fill(&self, width: u32, height: u32) -> Self
Scale to fill the given bounds, preserving aspect ratio (may overflow bounds).